from collections import deque


class Dinic:
    def __init__(self, n):
        self.n = n
        self.links = [[] for _ in range(n)]
        self.depth = None
        self.progress = None
 
    def add_link(self, _from, to, cap):
        self.links[_from].append([cap, to, len(self.links[to])])
        self.links[to].append([0, _from, len(self.links[_from]) - 1])
 
    def bfs(self, s):
        depth = [-1] * self.n
        depth[s] = 0
        q = deque([s])
        while q:
            v = q.popleft()
            for cap, to, rev in self.links[v]:
                if cap > 0 and depth[to] < 0:
                    depth[to] = depth[v] + 1
                    q.append(to)
        self.depth = depth
 
    def dfs(self, v, t, flow):
        if v == t:
            return flow
        links_v = self.links[v]
        for i in range(self.progress[v], len(links_v)):
            self.progress[v] = i
            cap, to, rev = link = links_v[i]
            if cap == 0 or self.depth[v] >= self.depth[to]:
                continue
            d = self.dfs(to, t, min(flow, cap))
            if d == 0:
                continue
            link[0] -= d
            self.links[to][rev][0] += d
            return d
        return 0
 
    def max_flow(self, s, t):
        flow = 0
        while True:
            self.bfs(s)
            if self.depth[t] < 0:
                return flow
            self.progress = [0] * self.n
            current_flow = self.dfs(s, t, float('inf'))
            while current_flow > 0:
                flow += current_flow
                current_flow = self.dfs(s, t, float('inf'))

def main():
    N = int(input())
    rl = []
    bl = []
    mf = Dinic(2 * N + 2)
    for i in range(N):
        mf.add_link(0, i+1, 1)
        mf.add_link(i+N+1, 2*N+1, 1)
    for _ in range(N):
        a, b = map(int, input().split())
        rl.append((a,b))
    for _ in range(N):
        c, d = map(int, input().split())
        bl.append((c, d))
    for i in range(N):
        for j in range(N):
            if rl[i][0] < bl[j][0] and rl[i][1] < bl[j][1]:
                mf.add_link(i+1, j+N+1, 1)
    return mf.max_flow(0, 2*N+1)
print(main())
